#
# spec file for package python-onionshare
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2018 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%define modname onionshare
Name:           python-%{modname}
Version:        2.2
Release:        bp155.2.12
Summary:        Self-hosting Tor Onion Service based file sharing
License:        GPL-3.0-or-later
URL:            https://github.com/micahflee/onionshare
Source0:        https://github.com/micahflee/onionshare/archive/v%{version}.tar.gz#/%{modname}-%{version}.tar.gz
Source1:        %{modname}.desktop
BuildRequires:  %{python_module Flask-HTTPAuth}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module PySocks}
BuildRequires:  %{python_module nautilus}
BuildRequires:  %{python_module pycrypto}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module stem}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       python-Flask
Requires:       python-Flask-HTTPAuth
Requires:       python-pycrypto
Requires:       python-pytest
Requires:       python-qt5
Requires:       python-stem
Requires:       tor
BuildArch:      noarch
%python_subpackages

%description
OnionShare lets the user share files securely and anonymously. It
works by starting a web server, making it accessible as a Tor Onion
Service, and generating an unguessable URL to access and download the
files. It does not require setting up a separate server or using a
third party file-sharing service. Files are hosted on the machine the
program is run on. The receiving user just needs to open the URL in
Tor Browser to download the file.

%prep
%setup -q -n %{modname}-%{version}
cp %{SOURCE1} .

%build
%python_build

%install
%python_install

mkdir -p %{buildroot}%{_datadir}/pixmaps
cp install/%{modname}80.xpm %{buildroot}%{_datadir}/pixmaps/%{modname}80.xpm

desktop-file-install --dir %{buildroot}%{_datadir}/applications/ %{modname}.desktop
%suse_update_desktop_file %{modname}

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%files %{python_files}
%python3_only %{_bindir}/%{modname}*
%{_datadir}/%{modname}*
%{_datadir}/pixmaps/*
%{_datadir}/*
%license LICENSE
%doc README.md
%{python_sitelib}/*

%changelog
* Wed Nov  6 2019 Axel Braun <axel.braun@gmx.de>
- Version 2.2
  * fix for desktop icon installation
  * New feature: Website mode, which allows publishing a static HTML website as an onion service
  * Allow individual files to be viewed or downloaded in Share mode, including the ability to browse into subdirectories and use breadcrumbs to navigate back
  * Show a counter when individual files or pages are viewed
  * Better History items including colors and status codes to differentiate between successful and failed requests
  * Swap out the random /slug suffix for HTTP basic authentication (when in non-public mode)
  * Hide the Tor connection settings if the ONIONSHARE_HIDE_TOR_SETTINGS environment variable is set (Tails compatibility)
  * Remove the NoScript XSS warning in Receive Mode now that the NoScript/Tor Browser bug is fixed. The ajax upload method still exists when javascript is enabled.
  * Better support for DragonFly BSD
  * Updated various dependencies, including Flask, Werkzeug, urllib3, requests, and PyQt5
  * Updated Tor to 0.4.1.5
  * Other minor bug fixes
  * New translations:
    Arabic (العربية)
    Dutch (Nederlands)
    Persian (فارسی)
    Romanian (Română)
    Serbian latin (Srpska (latinica))
  * Removed translations with fewer than 90%% of strings translated:
    Finnish (Suomi)
* Tue Aug 13 2019 Axel Braun <axel.braun@gmx.de>
- Version 2.1
  * New feature: Auto-start timer, which allows scheduling when the server starts
  * Renamed CLI argument --debug to --verbose
  * Make Tor connection timeout configurable as a CLI argument
  * Updated various dependencies, including to fix third-party security issues in urllib3, jinja2, and jQuery
  * Update Tor to 0.3.5.8
  * New translations:
    Traditional Chinese (正體中文 (繁體)),
    Simplified Chinese (中文 (简体))
    Finnish (Suomi)
    German (Deutsch)
    Icelandic (Íslenska)
    Irish (Gaeilge)
    Norwegian Bokmål (Norsk Bokmål)
    Polish (Polski)
    Portuguese Portugal (Português (Portugal))
    Telugu (తెలుగు)
    Turkish (Türkçe)
    Ukrainian (Українська)
  * Removed translations because less than 90%% of the strings were translated:
    Bengali (বাংলা)
    Persian (فارسی)
* Fri Feb 22 2019 Robert Frohl <rfrohl@suse.com>
- Version 2.0
  * Receiver mode allows you to receive files with OnionShare, instead of only
    sending files
  * Support for next generation onion services
  * Public mode feature, for public uses of OnionShare, which when enabled
    turns off slugs in the URL and removes the limit on how many 404 requests
    can be made
  * If you're sharing a single file, don't zip it up
  * Full support for meek_lite (Azure) bridges
  * Allow selecting your language from a dropdown
* Fri Dec 21 2018 Axel Braun <axel.braun@gmx.de>
- Version 1.3.2 to fix CVE-2018-19960 (boo#1120205)
* Wed Dec 12 2018 Jan Engelhardt <jengelh@inai.de>
- Trim a few redundancies from the descriptions.
* Wed Dec 12 2018 Ismail Dönmez <idonmez@suse.com>
- Use full source URLs to verify the integrity
  https://en.opensuse.org/SourceUrls
* Fri Nov 23 2018 Axel Braun <axel.braun@gmx.de>
- Version 1.3.1
  initial build on OBS
  thanks to scarabeus_iv for the testing part!
